@@ -16,7 +16,7 @@ class PoolConnection(DBHelper):
     def connect_cur(self):
         cur = None
         try:
-            conn, cur = self.conn_cur()
+            conn, cur = self._conn_cur()
             yield cur
             conn.commit()
         except:
