@@ -19,28 +19,23 @@ def with_mysql_reconnect(func):
             self._conn = None
 
     def _(self, *args, **argitems):
-        if self.type == 'mysql':
-            import MySQLdb as m
-        elif self.type == 'pymysql':
-            import pymysql as m
         trycount = 3
         while True:
             try:
                 x = func(self, *args, **argitems)
-            except m.OperationalError as e:
-                if e[0] >= 2000 and self._trans == 0:  # 客户端错误
+            except self._engine.OperationalError as e:
+                if e[0] >= 2000 and not self._transaction:  # 客户端错误
                     log.info(traceback.format_exc())
                     close_mysql_conn(self)
                     self._connect()
                     trycount -= 1
                     if trycount > 0:
                         continue
-
                 log.warning(traceback.format_exc())
                 raise
-            except (m.InterfaceError, m.InternalError):
+            except (self._engine.InterfaceError, self._engine.InternalError):
                 log.warning(traceback.format_exc())
-                if self._trans == 0:
+                if not self._transaction:
                     close_mysql_conn(self)
                     self._connect()
                     trycount -= 1
@@ -59,16 +54,16 @@ class MySQLConnection(DBHelper):
     type = "mysql"
 
     def __init__(self, name, engine, lasttime, status, role='master', *args, **kwargs):
-        self._name = name
-        self._engine = engine
-        self._args, self._kwargs = args, kwargs
-        self._conn = None
-        self._status = status
-        self._lasttime = lasttime
-        self._server_id = None
-        self._conn_id = 0
-        self._trans = 0  # is start transaction
-        self._role = role
+        self._name = name                       # 连接池名称
+        self._engine = engine                   # 数据库连接引擎，满足DB API 2.0规范
+        self._args, self._kwargs = args, kwargs # 数据库连接所传参数
+        self._conn = None                       # 连接存储位置
+        self._status = status                   # 连接状态
+        self._lasttime = lasttime               # 连接创建时间
+        self._server_id = None                  # MySQL服务唯一id
+        self._conn_id = 0                       # MySQL连接唯一id
+        self._transaction = False               # 是否正在执行事务
+        self._role = role                       # MySQL服务器在MySQL集群中的角色
         self.connect()
 
     def __str__(self):
@@ -96,7 +91,7 @@ class MySQLConnection(DBHelper):
         #      }
         self._conn = self._engine.connect(*self._args, **self._kwargs)
         self._conn.autocommit(1)
-        self._trans = 0
+        self._transaction = False
 
         cur = self._conn.cursor()
         cur.execute("show variables like 'server_id'")
@@ -114,7 +109,7 @@ class MySQLConnection(DBHelper):
                  self.type, self._conn_id % 10000,
                  self._name, self._kwargs.get('user', ''), self._role,
                  self._kwargs.get('host', ''), self._kwargs.get('port', 0),
-                 self._kwargs.get('db', ''))
+                 self._kwargs.get('database', ''))
 
     def cursor(self, *args, **kwargs):
         return self._conn.cursor(*args, **kwargs)
@@ -123,18 +118,26 @@ class MySQLConnection(DBHelper):
         log.info('server=%s|func=close|id=%d', self.type, self._conn_id % 10000)
         self._conn.close()
         self._conn = None
+    
+    def reconnect(self):
+        '''重新连接'''
+        try:
+            self.close()
+        except:
+            pass
+        self.connect()
 
     def begin(self, *args, **kwargs):
-        self._trans = 1
+        self._transaction = True
         begin = self._conn.begin
         begin(*args, **kwargs)
 
     def commit(self):
-        self._trans = 0
+        self._transaction = False
         self._conn.commit()
 
     def rollback(self):
-        self._trans = 0
+        self._transaction = False
         self._conn.rollback()
 
     def cancel(self):
@@ -191,17 +194,17 @@ class MySQLConnection(DBHelper):
     #     return ret[0][0]
 
     # def start(self):
-    #     self._trans = 1
+    #     self._transaction = True
     #     sql = "start transaction"
     #     return self.execute(sql)
 
     # def commit(self):
-    #     self._trans = 0
+    #     self._transaction = False
     #     sql = 'commit'
     #     return self.execute(sql)
 
     # def rollback(self):
-    #     self._trans = 0
+    #     self._transaction = False
     #     sql = 'rollback'
     #     return self.execute(sql)
 
@@ -212,7 +215,7 @@ class MySQLConnection(DBHelper):
 #          DBConnection.__init__(self, lasttime, status, *args, **kwargs)
 #
 #      def connect(self):
-#          self._trans = 0
+#          self._transaction = False
 #          self._conn = self._engine.connect(*args, **kwargs)
 #
 #      def useit(self):
@@ -230,6 +233,6 @@ class MySQLConnection(DBHelper):
 #          return ret[0][0]
 #
 #      def start(self):
-#          self._trans = 1
+#          self._transaction = True
 #          sql = "BEGIN"
 #          return self._conn.execute(sql)
