@@ -125,7 +125,8 @@ class DBHelper:
         ''' 字段名解析
         情况：'id','a.id','id as i', 'a.id as ai'
         '''
-        return '`%s`' % field.strip().replace('.', '`.`').replace(' as ', '` as `')
+        # return '`%s`' % field.strip().replace('.', '`.`').replace(' as ', '` as `')
+        return field
     
     def fields2sql(self, fields:Union[str, List[str], Tuple[str]]):
         ''' 解析fields
@@ -133,12 +134,17 @@ class DBHelper:
                ['id', 'a.name', 'imlf.phone as ip'], 
                ('id', 'a.name', 'imlf.phone as ip')
         '''
+        # if isinstance(fields, str):
+        #     fields = fields.strip()
+        #     if fields == '*':
+        #         return fields
+        #     fields = fields.split(',')
+        # return ','.join([self.field2sql(field) for field in fields])
         if isinstance(fields, str):
-            fields = fields.strip()
-            if fields == '*':
-                return fields
-            fields = fields.split(',')
-        return ','.join([self.field2sql(field) for field in fields])
+            return fields
+        else: 
+            return ','.join(list(fields))
+
 
     def table2sql(self, table:str):
         ''' 字段名解析
@@ -504,6 +510,7 @@ class DBHelper:
 
 
 class SimpleDBConnection(DBHelper):
+    type = 'simpledb'
     def __init__(self, engine, *args, **kwargs):
         self._conn = None
         self._args, self._kwargs = args, kwargs
