@@ -7,6 +7,7 @@ from contextlib import contextmanager
 from .utils import log
 # from .dbconnect import SQLiteConnection
 from .dbconnect import MySQLConnection
+from .dboconnect import MySQLConnectionO
 from .pooled_db import PooledDB
 from .conf import Config, POOLTYPE
 
@@ -21,24 +22,29 @@ class DBPoolBase(object):
 
 class DBPool(DBPoolBase):
     def __init__(self, name, engine, mincached=1, maxconnections=20, timeout=10, *args, **kwargs):
-        self._name = name
-        self._engine = engine
-        self._mincached = mincached
-        self._maxconnections = maxconnections
-        self._timeout = timeout
-        self._args, self._kwargs = args, kwargs
-        self._idle_cache = []
-        self._idle_using = []
-        self._connection_class = MySQLConnection
+        self._name = name                       # 数据库连接池名称
+        self._engine = engine                   # 数据库连接引擎，满足DB API 2.0规范
+        self._mincached = mincached             # 连接池最小缓存个数
+        self._maxconnections = maxconnections   # 连接池最大连接个数
+        self._timeout = timeout                 # 连接不使用状态释放超时时间
+        self._args, self._kwargs = args, kwargs # 数据库连接所传参数
+        self._idle_cache = []                   # 数据库缓存连接存储列表
+        self._idle_using = []                   # 数据库正在使用连接列表
+        config = Config()
+        if config.ext and config.ext=='dbo':
+            self._connection_class = MySQLConnectionO
+        else:
+            self._connection_class = MySQLConnection # MySQL连接封装类
         # x = globals()
         # for v in x.values():
         #     if str(type(v)) == "<class 'type'>" and v != DBConnection and issubclass(v, DBConnection):
         #         self._connection_class[v.type] = v
-        self._lock = threading.Lock()
-        self._cond = threading.Condition(self._lock)
+        self._lock = threading.Lock()            # 线程锁
+        self._cond = threading.Condition(self._lock)   # 条件锁
         self.open(self._mincached)
 
     def synchronize(func):
+        """获取线程锁"""
         def _(self, *args, **kwargs):
             self._lock.acquire()
             x = None
@@ -50,6 +56,7 @@ class DBPool(DBPoolBase):
         return _
 
     def open(self, n=1):
+        """增加新连接"""
         newconns = []
         for i in range(0, n):
             myconn = self._connection_class(
@@ -64,6 +71,7 @@ class DBPool(DBPoolBase):
         self._idle_cache += newconns
 
     def clear_timeout(self):
+        """释放不使用超时的数据库连接"""
         # log.info('try clear timeout conn ...')
         now = time.time()
         dels = []
@@ -78,12 +86,13 @@ class DBPool(DBPoolBase):
         if dels:
             log.debug('close timeout db conn:%d', len(dels))
         for c in dels:
-            if c.conn:
+            if c._conn:
                 c.close()
             self._idle_cache.remove(c)
 
     @synchronize
     def acquire(self, timeout=10):
+        """从连接池中获取一个连接"""
         start = time.time()
         while len(self._idle_cache) == 0:
             if len(self._idle_cache) + len(self._idle_using) < self._maxconnections:
@@ -108,8 +117,9 @@ class DBPool(DBPoolBase):
 
     @synchronize
     def release(self, conn):
+        """把数据库连接放回到数据库连接池中"""
         if conn:
-            if conn._trans:
+            if conn._transaction:
                 log.debug('realse close conn use transaction')
                 conn.close()
                 # conn.connect()
@@ -126,6 +136,7 @@ class DBPool(DBPoolBase):
             conn.alive()
 
     def size(self):
+        """连接池的当前大小"""
         return len(self._idle_cache), len(self._idle_using)
 
 def checkalive(name=None):
@@ -141,10 +152,11 @@ def checkalive(name=None):
         time.sleep(300)
 
 
-def init_pool(db_conf, ptype='simple', debug=True):
+def init_pool(db_conf, ptype='simple', debug=True, ext=None):
     global dbpool
     config = Config()
     config.debug = debug
+    config.ext = ext
     if ptype not in POOLTYPE.to_list():
         raise Exception("ptype must in [%s]" % POOLTYPE.to_list())
     config.ptype = ptype
