@@ -1,62 +1,21 @@
 """SteadyDB - hardened DB-API 2 connections.
+基于任意DB-API 2兼容的数据库接口模块实现与数据库的稳定连接。
+当连接关闭或数据库连接丢失或连接的使用次数超过可选的使用限制时，连接将透明地重新打开。
+当因为失去了连接而无法执行数据库操作时，数据库游标也会透明地重新打开。
+只有在执行后连接丢失时，当已经从数据库中提取行时，才会给出一个错误，游标不会自动重新打开，
+因为在这种情况下没有可靠的方法恢复游标的状态。通过begin()调用标记为处于事务中的连接也不会被静默替换。
 
-Implements steady connections to a database based on an
-arbitrary DB-API 2 compliant database interface module.
+数据库连接丢失的典型情况是由于维护原因关闭并重新启动数据库服务器或中间的防火墙。
+在这种情况下，所有数据库连接都将变得不可用，即使数据库服务可能已经再次可用。
 
-The connections are transparently reopened when they are
-closed or the database connection has been lost or when
-they are used more often than an optional usage limit.
-Database cursors are transparently reopened as well when
-the execution of a database operation cannot be performed
-due to a lost connection.  Only if the connection is lost
-after the execution, when rows are already fetched from the
-database, this will give an error and the cursor will not
-be reopened automatically, because there is no reliable way
-to recover the state of the cursor in such a situation.
-Connections which have been marked as being in a transaction
-with a begin() call will not be silently replaced either.
+该模块提供的“steady”连接将使数据库连接立即可用。
 
-A typical situation where database connections are lost
-is when the database server or an intervening firewall is
-shutdown and restarted for maintenance reasons.  In such a
-case, all database connections would become unusable, even
-though the database service may be already available again.
+这种方法会产生一个稳定的数据库连接，PooledDB或PersistentDB可以使用它在线程环
+境(如“Webware for Python”的应用服务器)中创建到数据库的池连接或持久连接。
 
-The "hardened" connections provided by this module will
-make the database connections immediately available again.
-
-This approach results in a steady database connection that
-can be used by PooledDB or PersistentDB to create pooled or
-persistent connections to a database in a threaded environment
-such as the application server of "Webware for Python."
-Note, however, that the connections themselves may not be
-thread-safe (depending on the used DB-API module).
-
-For the Python DB-API 2 specification, see:
-    https://www.python.org/dev/peps/pep-0249/
-For information on Webware for Python, see:
-    https://webwareforpython.github.io/w4py/
-
-Usage:
-
-You can use the connection constructor connect() in the same
-way as you would use the connection constructor of a DB-API 2
-module if you specify the DB-API 2 module to be used as the
-first parameter, or alternatively you can specify an arbitrary
-constructor function returning new DB-API 2 compliant connection
-objects as the first parameter.  Passing just a function allows
-implementing failover mechanisms and load balancing strategies.
-
-You may also specify a usage limit as the second parameter
-(set it to None if you prefer unlimited usage), an optional
-list of commands that may serve to prepare the session as a
-third parameter, the exception classes for which the failover
-mechanism shall be applied, and you can specify whether is is
-allowed to close the connection (by default this is true).
-When the connection to the database is lost or has been used
-too often, it will be transparently reset in most situations,
-without further notice.
+但是请注意，连接本身可能不是线程安全的(取决于所使用的DB-API模块)。
 
+用法:
     import pgdb  # import used DB-API 2 module
     from dbutils.steady_db import connect
     db = connect(pgdb, 10000, ["set datestyle to german"],
@@ -71,22 +30,6 @@ without further notice.
     ...
     db.close()
 
-
-Ideas for improvement:
-
-* Alternatively to the maximum number of uses,
-  implement a maximum time to live for connections.
-* Optionally log usage and loss of connection.
-
-
-Copyright, credits and license:
-
-* Contributed as supplement for Webware for Python and PyGreSQL
-  by Christoph Zwerschke in September 2005
-* Allowing engine functions as first parameter as in SQLAlchemy
-  suggested by Ezio Vernacotola in December 2006
-
-Licensed under the MIT license.
 """
 
 import sys
@@ -106,27 +49,20 @@ class InvalidCursor(SteadyDBError):
 def connect(
         engine, maxusage=None, setsession=None,
         failures=None, ping=1, closeable=True, *args, **kwargs):
-    """A tough version of the connection constructor of a DB-API 2 module.
-
-    engine: either an arbitrary function returning new DB-API 2 compliant
-        connection objects or a DB-API 2 compliant database module
-    maxusage: maximum usage limit for the underlying DB-API 2 connection
-        (number of database operations, 0 or None means unlimited usage)
-        callproc(), execute() and executemany() count as one operation.
-        When the limit is reached, the connection is automatically reset.
-    setsession: an optional list of SQL commands that may serve to prepare
-        the session, e.g. ["set datestyle to german", "set time zone mez"]
-    failures: an optional exception class or a tuple of exception classes
-        for which the failover mechanism shall be applied, if the default
-        (OperationalError, InternalError) is not adequate
-    ping: determines when the connection should be checked with ping()
-        (0 = None = never, 1 = default = when _ping_check() is called,
-        2 = whenever a cursor is created, 4 = when a query is executed,
-        7 = always, and all other bit combinations of these values)
-    closeable: if this is set to false, then closing the connection will
-        be silently ignored, but by default the connection can be closed
-    args, kwargs: the parameters that shall be passed to the engine
-        function or the connection constructor of the DB-API 2 module
+    """基于DB-API 2模块的稳定连接。
+    engine: 可以是返回新的符合DB-API 2的连接对象的任意函数，也可以是符合DB-API 2的数据库模块
+    maxusage: 底层DB-API 2连接的最大使用限制(数据库操作的数量，0或None意味着无限制的使用)
+              callproc()、execute()和executemany()计数为一个操作。当达到限制时，连接将自动复位。
+    setsession: 一个可选的SQL命令列表，可以用来准备会话，
+                例如["set datestyle to german"， "set time zone mez"]
+    failures: 如果默认值(OperationalError, InternalError)不够充分，
+              则应应用故障转移机制的可选异常类或异常类的元组
+    ping: 使用ping()确定何时应该检查连接
+         (0 = None = never, 1 = default = when _ping_check()被调用，
+         2 =每当创建游标时，4 =当执行查询时，
+         7 = always，以及这些值的所有其他位组合)
+    closeable: 如果将此设置为false，则关闭连接将被静默忽略，但默认情况下可以关闭连接
+    args, kwargs: 应该传递给引擎函数或DB-API 2模块的连接构造函数的参数
     """
     return SteadyDBConnection(
         engine, maxusage, setsession,
@@ -134,16 +70,15 @@ def connect(
 
 
 class SteadyDBConnection(SimpleDBConnection):
-    """A "tough" version of DB-API 2 connections."""
+    """基于DB-API 2模块的稳定连接。"""
 
     def __init__(
             self, engine, maxusage=None, setsession=None,
             failures=None, ping=1, closeable=True, *args, **kwargs):
-        """Create a "tough" DB-API 2 connection."""
-        # basic initialization to make finalizer work
+        # 连接存储位置
         self._conn = None
         self._closed = True
-        # proper initialization of the connection
+        # 适当的初始化连接器
         try:
             self._engine = engine.connect
             self._dbapi = engine
@@ -287,6 +222,12 @@ class SteadyDBConnection(SimpleDBConnection):
             raise error  # re-raise the original error again
         return conn
 
+    def reconnect(self):
+        '''重新连接'''
+        self._close()
+        self._store(self._create())
+        self.conn_info()
+
     def _setsession(self, conn=None):
         """Execute the SQL commands for session preparation."""
         if conn is None:
@@ -330,11 +271,8 @@ class SteadyDBConnection(SimpleDBConnection):
                 pass
 
     def _ping_check(self, ping=1, reconnect=True):
-        """Check whether the connection is still alive using ping().
-
-        If the the underlying connection is not active and the ping
-        parameter is set accordingly, the connection will be recreated
-        unless the connection is currently inside a transaction.
+        """使用ping()检查连接是否仍然活跃。
+        如果底层连接不活跃，则将重新创建连接, 除非连接正处在事务中。
         """
         if ping & self._ping:
             try:  # if possible, ping the connection
