@@ -1,5 +1,6 @@
 import time
 import logging
+import traceback
 from .conf import LOG_CONF, Config, POOLTYPE
 from . import logger
 logger.install('stdout')
@@ -43,17 +44,17 @@ def timeit(func):
                 conn.type, conn.conn_id % 10000,
                 conn.name, dbcf.get('user', ''),
                 dbcf.get('host', ''), dbcf.get('port', 0),
-                dbcf.get('db', ''),
+                dbcf.get('database', ''),
                 len(conn.pool.dbconn_idle),
                 len(conn.pool.dbconn_using),
-                conn.pool.max_conn, conn.trans,
+                conn.pool.max_conn, conn._transaction,
                 int((endtm - starttm) * 1000000),
                 str(ret), num,
                 sql, err)
     return _
 
 def timesql(func):
-    def _(*args, **kwargs):
+    def _(self, sql, *args, **kwargs):
         config = Config()
         if config.debug:
             starttm = time.time()
@@ -61,7 +62,31 @@ def timesql(func):
             num = 0
             err = ''
         try:
-            retval = func(*args, **kwargs)
+            for i in range(config.trycount):
+                try:
+                    retval = func(self, sql, *args, **kwargs)
+                    break
+                except (self._engine.OperationalError, 
+                        self._engine.InterfaceError, 
+                        self._engine.InternalError) as e:  # 如果是连接错误
+                    """
+                    OperationalError:
+                        对于与数据库操作相关且不一定在程序员控制下的错误所引发的异常，
+                        例如意外断开连接、找不到数据源名称、事务无法处理、处理过程中发生内存分配错误等。
+                    InterfaceError:
+                        对于与数据库接口而非数据库本身相关的错误引发的异常
+                    InternalError:
+                        当数据库遇到内部错误时引发的异常，例如游标不再有效、事务不同步等。
+                    """
+                    log.warning(traceback.format_exc())
+                    if not self._transaction:
+                        self.reconnect()
+                        continue
+                    raise e
+                except Exception as e:
+                    raise e
+            else:
+                retval = None
             if config.debug:
                 if isinstance(retval, list):
                     num = len(retval)
@@ -77,30 +102,29 @@ def timesql(func):
         finally:
             if config.debug:
                 endtm = time.time()
-                conn = args[0]
                 # dbcf = conn.pool.dbcf
-                dbcf = conn._kwargs
-                sql = repr(args[1])
+                dbcf = self._kwargs
+                sql = repr(sql)
                 if not LOG_CONF.get('log_allow_print_sql', True):
                     sql = '***'
 
                 if config.ptype == POOLTYPE.SIMPLE:
                     log.info(
                         'server=%s|id=%d|name=%s|user=%s|addr=%s:%d|db=%s|idle=%d|busy=%d|max=%d|trans=%d|time=%d|ret=%s|num=%d|sql=%s|err=%s',
-                        conn.type, conn._conn_id % 10000,
-                        conn._name, dbcf.get('user', ''),
+                        self.type, self._conn_id % 10000,
+                        self._name, dbcf.get('user', ''),
                         dbcf.get('host', ''), dbcf.get('port', 0),
-                        dbcf.get('db', ''),
-                        len(conn.pool._idle_cache),
-                        len(conn.pool._idle_using),
-                        conn.pool._maxconnections, conn._trans,
+                        dbcf.get('database', ''),
+                        len(self.pool._idle_cache),
+                        len(self.pool._idle_using),
+                        self.pool._maxconnections, 1 if self._transaction else 0,
                         int((endtm - starttm) * 1000000),
                         str(ret), num,
                         sql, err)
                 else:
                     log.info(
                         'server=%s|conn=%d|user=%s|addr=%s:%d|db=%s|time=%d|ret=%s|num=%d|sql=%s|err=%s' % (
-                        getattr(conn, '_server_id', '0'), getattr(conn, '_conn_id', 0) % 10000,
+                        getattr(self, '_server_id', '0'), getattr(self, '_conn_id', 0) % 10000,
                         dbcf.get('user', ''), dbcf.get('host', ''), 
                         dbcf.get('port', 0), dbcf.get('database', ''),
                         int((endtm - starttm) * 1000000),
